#!/usr/bin/env python

# Set this to True to enable building extensions using Cython.
# Set it to False to build extensions from the CPP file (that
# was previously created using Cython).
# Set it to 'auto' to build with Cython if available, otherwise
# from the CPP file.
# Warning: I can notice some runtime errors with cython 0.15 that disappear with 0.17.4
USE_CYTHON = False
#USE_CYTHON = 'auto'


from distutils.core import setup
from distutils.extension import Extension

if USE_CYTHON:
    try:
        from Cython.Distutils import build_ext
    except ImportError:
        if USE_CYTHON=='auto':
            USE_CYTHON=False
        else:
            raise

cmdclass = { }
ext_modules = [ ]

if USE_CYTHON:
    ext_modules+=[Extension(
                   "giacpy",                 # name of extension
                   ["giacpy.pyx"], #  our Cython source
                   libraries=['giac'],
                   language="c++")]
    cmdclass={'build_ext': build_ext}

else:
    ext_modules+=[Extension(
                   "giacpy",                 # name of extension
                   ["giacpy.cpp"], #  the cpp file already created by Cython
                   libraries=['giac'],
                   language="c++")]

setup(


    name='giacpy',
    version='0.2.4', 
    description='A Cython frontend to the c++ library giac. (Computer Algebra System)',
    author='Frederic Han',
    author_email="han@math.jussieu.fr",
    url='http://www.math.jussieu.fr/~han/xcas/giacpy/',
    long_description=open('README.txt').read(),
    license='GPLv2 or above',
    ext_modules=ext_modules,
    cmdclass=cmdclass
    )



